# testeasydubins

## Installation

You can install the testeasydubins from [PyPI](https://pypi.org/project/testeasydubins/):

    pip install testeasydubins

The testeasydubins is supported on Python 2.7, as well as Python 3.4 and above.

## How to use

To call the testeasydubins in your own Python code, by importing from the `testeasydubins` package:

    >>> from testeasydubins import dubin_path
